import { ethers_contracts } from '@certusone/wormhole-sdk';
import { ChainName, ChainId, Contracts, TokenBridgeRelayer, ContractsAbstract, Wormhole } from '@wormhole-foundation/connect-sdk';
/**
 * @category EVM
 * Evm Contracts class. Contains methods for accessing ts interfaces for all available contracts
 */
export declare class EvmContracts extends ContractsAbstract {
    protected _contracts: Map<ChainName, any>;
    protected wormhole: Wormhole;
    constructor(wormholeBase: Wormhole);
    getContracts(chain: ChainName | ChainId): Contracts | undefined;
    mustGetContracts(chain: ChainName | ChainId): Contracts;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, undefined if not found
     */
    getCore(chain: ChainName | ChainId): ethers_contracts.Wormhole | undefined;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    mustGetCore(chain: ChainName | ChainId): ethers_contracts.Wormhole;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, undefined if not found
     */
    getBridge(chain: ChainName | ChainId): ethers_contracts.Bridge | undefined;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    mustGetBridge(chain: ChainName | ChainId): ethers_contracts.Bridge;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, undefined if not found
     */
    getNftBridge(chain: ChainName | ChainId): ethers_contracts.NFTBridge | undefined;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    mustGetNftBridge(chain: ChainName | ChainId): ethers_contracts.NFTBridge;
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, undefined if not found
     */
    getTokenBridgeRelayer(chain: ChainName | ChainId): TokenBridgeRelayer | undefined;
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, errors if not found
     */
    mustGetTokenBridgeRelayer(chain: ChainName | ChainId): any;
}
